pub struct Idx<'n, I: Index = usize> { /* private fields */ }Expand description
Implementations
Sourceimpl<'n, I: Index> Idx<'n, I>
impl<'n, I: Index> Idx<'n, I>
Sourcepub const unsafe fn new_unbound(idx: I) -> Self
pub const unsafe fn new_unbound(idx: I) -> Self
Sourcepub unsafe fn new_unchecked(idx: I, dim: Dim<'n>) -> Self
pub unsafe fn new_unchecked(idx: I, dim: Dim<'n>) -> Self
create new branded value with the same brand as Dim.
safety
the behavior is undefined unless idx < dim and idx <= i::signed::max.
Sourcepub fn new_checked(idx: I, dim: Dim<'n>) -> Self
pub fn new_checked(idx: I, dim: Dim<'n>) -> Self
create new branded value with the same brand as Dim.
panics
panics unless idx < dim and idx <= i::signed::max.
Sourceimpl<'n, I: Index> Idx<'n, I>
impl<'n, I: Index> Idx<'n, I>
Sourcepub const fn to_incl(self) -> IdxInc<'n, I>
pub const fn to_incl(self) -> IdxInc<'n, I>
returns the index, bounded inclusively by the value tied to 'n.
Sourcepub fn next(self) -> IdxInc<'n, I>
pub fn next(self) -> IdxInc<'n, I>
returns the next index, bounded inclusively by the value tied to 'n.
Sourcepub fn excl(self) -> IdxInc<'n, I>
pub fn excl(self) -> IdxInc<'n, I>
returns the index, bounded inclusively by the value tied to 'n.
Sourcepub fn from_slice_mut_checked<'a>(
slice: &'a mut [I],
size: Dim<'n>,
) -> &'a mut [Idx<'n, I>]
pub fn from_slice_mut_checked<'a>( slice: &'a mut [I], size: Dim<'n>, ) -> &'a mut [Idx<'n, I>]
assert that the values of slice are all bounded by size.
Sourcepub unsafe fn from_slice_mut_unchecked<'a>(
slice: &'a mut [I],
) -> &'a mut [Idx<'n, I>]
pub unsafe fn from_slice_mut_unchecked<'a>( slice: &'a mut [I], ) -> &'a mut [Idx<'n, I>]
assume that the values of slice are all bounded by the value tied to 'n.
Sourcepub fn from_slice_ref_checked<'a>(
slice: &'a [I],
size: Dim<'n>,
) -> &'a [Idx<'n, I>]
pub fn from_slice_ref_checked<'a>( slice: &'a [I], size: Dim<'n>, ) -> &'a [Idx<'n, I>]
assert that the values of slice are all bounded by size.
Sourcepub unsafe fn from_slice_ref_unchecked<'a>(slice: &'a [I]) -> &'a [Idx<'n, I>]
pub unsafe fn from_slice_ref_unchecked<'a>(slice: &'a [I]) -> &'a [Idx<'n, I>]
assume that the values of slice are all bounded by the value tied to 'n.