IdxInc

Struct IdxInc 

pub struct IdxInc<'n, I: Index = usize> { /* private fields */ }
lifetime branded partition index.

safety

the type’s safety invariant is that all instances of this type are valid partition places for Dim<'n> and less than or equal to i::signed::max.

Implementations

Source

impl<'n> IdxInc<'n>

pub const ZERO: Self

zero index

Source

impl<'n, I: Index> IdxInc<'n, I>

pub const unsafe fn new_unbound(idx: I) -> Self

create new branded value with an arbitrary brand.

safety

see struct safety invariant.

pub unsafe fn new_unchecked(idx: I, dim: Dim<'n>) -> Self

create new branded value with the same brand as Dim.

safety

the behavior is undefined unless idx <= dim.

pub fn new_checked(idx: I, dim: Dim<'n>) -> Self

create new branded value with the same brand as Dim.

panics

panics unless idx <= dim.

pub const fn unbound(self) -> I

returns the unconstrained value.

pub fn zx(self) -> IdxInc<'n>

zero-extends the internal value into a usize.

Source

impl<'n> IdxInc<'n>

pub fn to( self, upper: IdxInc<'n>, ) -> impl Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<'n>>

returns an iterator over the indices between self and to.

pub fn range_to( self, upper: IdxInc<'n>, ) -> impl Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<'n>>

returns an iterator over the indices between self and to.