pub struct Dim<'n> { /* private fields */ }Expand description
lifetime branded length
safety
the type’s safety invariant is that all instances of this type with the same lifetime correspond to the same length.
Implementations
Sourceimpl<'n> Dim<'n>
impl<'n> Dim<'n>
Sourcepub fn with<R>(dim: usize, f: impl for<'dim> FnOnce(Dim<'dim>) -> R) -> R
pub fn with<R>(dim: usize, f: impl for<'dim> FnOnce(Dim<'dim>) -> R) -> R
create new branded value with the value dim.
Sourcepub const unsafe fn new_unbound(dim: usize) -> Self
pub const unsafe fn new_unbound(dim: usize) -> Self
Sourcepub const fn partition<'head, 'tail>(
self,
midpoint: IdxInc<'n>,
head: Guard<'head>,
tail: Guard<'tail>,
) -> Partition<'head, 'tail, 'n>
pub const fn partition<'head, 'tail>( self, midpoint: IdxInc<'n>, head: Guard<'head>, tail: Guard<'tail>, ) -> Partition<'head, 'tail, 'n>
partitions self into two segments as specifiedd by the midpoint.
Sourcepub fn head_partition<'head, 'tail>(
self,
head: Dim<'head>,
tail: Guard<'tail>,
) -> Partition<'head, 'tail, 'n>
pub fn head_partition<'head, 'tail>( self, head: Dim<'head>, tail: Guard<'tail>, ) -> Partition<'head, 'tail, 'n>
partitions self into two segments.
Sourcepub fn advance(self, start: Idx<'n>, len: usize) -> IdxInc<'n>
pub fn advance(self, start: Idx<'n>, len: usize) -> IdxInc<'n>
returns start advanced by len units, saturated to self
Sourcepub fn indices(
self,
) -> impl Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<'n>>
pub fn indices( self, ) -> impl Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<'n>>
returns an iterator over the indices between 0 and self.
Sourcepub fn par_indices(self) -> impl IndexedParallelIterator<Item = Idx<'n>>
pub fn par_indices(self) -> impl IndexedParallelIterator<Item = Idx<'n>>
returns an iterator over the indices between 0 and self.
Sourceimpl<'size> Dim<'size>
impl<'size> Dim<'size>
Sourcepub fn check<I: Index>(self, idx: I) -> Idx<'size, I>
pub fn check<I: Index>(self, idx: I) -> Idx<'size, I>
check that the index is bounded by self, or panic otherwise.
Sourcepub fn idx<I: Index>(self, idx: I) -> Idx<'size, I>
pub fn idx<I: Index>(self, idx: I) -> Idx<'size, I>
check that the index is bounded by self, or panic otherwise.