pub struct IdxInc<'n, I: Index = usize> { /* private fields */ }Expand description
Implementations
Sourceimpl<'n, I: Index> IdxInc<'n, I>
impl<'n, I: Index> IdxInc<'n, I>
Sourcepub const unsafe fn new_unbound(idx: I) -> Self
pub const unsafe fn new_unbound(idx: I) -> Self
Sourcepub unsafe fn new_unchecked(idx: I, dim: Dim<'n>) -> Self
pub unsafe fn new_unchecked(idx: I, dim: Dim<'n>) -> Self
create new branded value with the same brand as Dim.
safety
the behavior is undefined unless idx <= dim.
Sourcepub fn new_checked(idx: I, dim: Dim<'n>) -> Self
pub fn new_checked(idx: I, dim: Dim<'n>) -> Self
Sourceimpl<'n> IdxInc<'n>
impl<'n> IdxInc<'n>
Sourcepub fn to(
self,
upper: IdxInc<'n>,
) -> impl Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<'n>>
pub fn to( self, upper: IdxInc<'n>, ) -> impl Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<'n>>
returns an iterator over the indices between self and to.
Sourcepub fn range_to(
self,
upper: IdxInc<'n>,
) -> impl Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<'n>>
pub fn range_to( self, upper: IdxInc<'n>, ) -> impl Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<'n>>
returns an iterator over the indices between self and to.